@@ -42,6 +42,7 @@ module Network.AWS.CodeDeploy.GetDeployment
     , gdrDeploymentInfo
     ) where
 
+import Network.AWS.Data (Object)
 import Network.AWS.Prelude
 import Network.AWS.Request.JSON
 import Network.AWS.CodeDeploy.Types
@@ -63,7 +64,8 @@ getDeployment p1 = GetDeployment
     { _gdDeploymentId = p1
     }
 
--- | An existing deployment ID within the AWS user account.
+-- | An existing deployment ID associated with the applicable IAM user or AWS
+-- account.
 gdDeploymentId :: Lens' GetDeployment Text
 gdDeploymentId = lens _gdDeploymentId (\s a -> s { _gdDeploymentId = a })
 
